::: spotify.api.API
    options:
      members:
        - get_episode
        - get_several_episodes
        - get_users_saved_episodes
        - save_episodes_for_user
        - remove_users_saved_episodes
        - check_users_saved_episodes
::: spotify.models.SimpleEpisode
::: spotify.models.Episode
::: spotify.models.SavedEpisode